import Flutter
import UIKit
import ChatProvidersSDK
import ChatSDK
import MessagingSDK
import CommonUISDK

public class ZendeskClassicPlugin: UIViewController, FlutterPlugin {
    private var aObjNavi: UINavigationController?
    
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "zendesk_classic", binaryMessenger: registrar.messenger())
    let instance = ZendeskClassicPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
     

    switch call.method {
    case "getPlatformVersion":
      result("iOS " + UIDevice.current.systemVersion)
    case "chat":
        let args = call.arguments as? Dictionary<String, Any>

        let chatAccountKey = args?["chatAccountKey"] as? String
        let botName = args?["botName"] as? String
        let barTintColor = args?["barTintColor"] as? Int
        let tintColor = args?["tintColor"] as? Int
        let backgroundColor = args?["backgroundColor"] as? Int
        

        Chat.initialize(accountKey: chatAccountKey ?? "")

        UINavigationBar.appearance().barTintColor = UIColor(rgb: barTintColor ?? 0xFFFF0000)
        UINavigationBar.appearance().tintColor = UIColor(rgb: tintColor ?? 0xFFFFFFFF)
        UINavigationBar.appearance().backgroundColor = UIColor(rgb: backgroundColor ?? 0xFF000000)
        UINavigationBar.appearance().titleTextAttributes = [NSAttributedString.Key.foregroundColor: UIColor.red ]
        UINavigationBar.appearance().largeTitleTextAttributes = [NSAttributedString.Key.foregroundColor: UIColor.red]
        UINavigationBar.appearance().titleTextAttributes = [NSAttributedString.Key(rawValue: NSAttributedString.Key.foregroundColor.rawValue): UIColor.orange]

        do {
          let chatEngine = try ChatEngine.engine()
            
            let messagingConfiguration = MessagingConfiguration()
            messagingConfiguration.isMultilineResponseOptionsEnabled = true
            messagingConfiguration.name = botName ?? ""
            
          let viewController = try Messaging.instance.buildUI(engines: [chatEngine], configs: [messagingConfiguration])

            let appDelegate = UIApplication.shared.delegate as! FlutterAppDelegate
            let window: UIWindow = ((appDelegate.window)!)
            
            let navController = UINavigationController(rootViewController: viewController)
            window.rootViewController?.present(navController, animated: true)
        } catch{
            print(error.localizedDescription)
        }
        result("chat")
    default:
      result(FlutterMethodNotImplemented)
    }
  }
}


extension UIColor {
   convenience init(red: Int, green: Int, blue: Int) {
       assert(red >= 0 && red <= 255, "Invalid red component")
       assert(green >= 0 && green <= 255, "Invalid green component")
       assert(blue >= 0 && blue <= 255, "Invalid blue component")

       self.init(red: CGFloat(red) / 255.0, green: CGFloat(green) / 255.0, blue: CGFloat(blue) / 255.0, alpha: 1.0)
   }

   convenience init(rgb: Int) {
       self.init(
           red: (rgb >> 16) & 0xFF,
           green: (rgb >> 8) & 0xFF,
           blue: rgb & 0xFF
       )
   }
}
