import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'zendesk_classic_platform_interface.dart';

/// An implementation of [ZendeskClassicPlatform] that uses method channels.
class MethodChannelZendeskClassic extends ZendeskClassicPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('zendesk_classic');
  final optionalMethodChannel = const OptionalMethodChannel('zendesk_classic');

  ///[initZendeskChat] Initialized the field required for zendesk chat
  /// [chatAccountKey] chat account key is required field to initialize a zendesk chat
  /// [barTintColor] is optional field which will use to set app bar color
  /// [tintColor] is optional field which will use to set tint color color
  /// [backgroundColor] is optional field which will use to set background color
  /// [botName] is optional field which will use to set bot name
  @override
  Future<void> initZendeskChat({
    required String chatAccountKey,
    int? barTintColor,
    int? tintColor,
    int? backgroundColor,
    String? botName,
  }) async {
    await optionalMethodChannel.invokeMethod<String>('chat', {
      'chatAccountKey': chatAccountKey,
      'barTintColor': barTintColor,
      'tintColor': tintColor,
      'backgroundColor': backgroundColor,
      'botName': botName,
    });
  }
}
