import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'zendesk_classic_method_channel.dart';

abstract class ZendeskClassicPlatform extends PlatformInterface {
  /// Constructs a ZendeskClassicPlatform.
  ZendeskClassicPlatform() : super(token: _token);

  static final Object _token = Object();

  static ZendeskClassicPlatform _instance = MethodChannelZendeskClassic();

  /// The default instance of [ZendeskClassicPlatform] to use.
  ///
  /// Defaults to [MethodChannelZendeskClassic].
  static ZendeskClassicPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [ZendeskClassicPlatform] when
  /// they register themselves.
  static set instance(ZendeskClassicPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  ///[initZendeskChat] Initialized the field required for zendesk chat
  /// [chatAccountKey] chat account key is required field to initialize a zendesk chat
  /// [barTintColor] is optional field which will use to set app bar color
  /// [tintColor] is optional field which will use to set tint color color
  /// [backgroundColor] is optional field which will use to set background color
  /// [botName] is optional field which will use to set bot name
  Future<void> initZendeskChat({
    required String chatAccountKey,
    int? barTintColor,
    int? tintColor,
    int? backgroundColor,
    String? botName,
  }) {
    throw UnimplementedError('initZendeskChat has not been implemented.');
  }
}
